@@ -1,9 +1,10 @@
+/* Note: This file is no longer generated.  See the comment in gmarshal.list */
 #ifndef __G_MARSHAL_H__
 #define __G_MARSHAL_H__
 
 G_BEGIN_DECLS
 
-/* VOID:VOID (/usr/obj/i386/glib2-2.2.3/glib-2.2.3/gobject/gmarshal.list:26) */
+/* VOID:VOID (./gmarshal.list:6) */
 extern void g_cclosure_marshal_VOID__VOID (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -11,7 +12,7 @@ extern void g_cclosure_marshal_VOID__VOID (GClosure     *closure,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
 
-/* VOID:BOOLEAN (/usr/obj/i386/glib2-2.2.3/glib-2.2.3/gobject/gmarshal.list:27) */
+/* VOID:BOOLEAN (./gmarshal.list:7) */
 extern void g_cclosure_marshal_VOID__BOOLEAN (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -19,7 +20,7 @@ extern void g_cclosure_marshal_VOID__BOOLEAN (GClosure     *closure,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
 
-/* VOID:CHAR (/usr/obj/i386/glib2-2.2.3/glib-2.2.3/gobject/gmarshal.list:28) */
+/* VOID:CHAR (./gmarshal.list:8) */
 extern void g_cclosure_marshal_VOID__CHAR (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -27,7 +28,7 @@ extern void g_cclosure_marshal_VOID__CHAR (GClosure     *closure,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
 
-/* VOID:UCHAR (/usr/obj/i386/glib2-2.2.3/glib-2.2.3/gobject/gmarshal.list:29) */
+/* VOID:UCHAR (./gmarshal.list:9) */
 extern void g_cclosure_marshal_VOID__UCHAR (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -35,7 +36,7 @@ extern void g_cclosure_marshal_VOID__UCHAR (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:INT (/usr/obj/i386/glib2-2.2.3/glib-2.2.3/gobject/gmarshal.list:30) */
+/* VOID:INT (./gmarshal.list:10) */
 extern void g_cclosure_marshal_VOID__INT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -43,7 +44,7 @@ extern void g_cclosure_marshal_VOID__INT (GClosure     *closure,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
 
-/* VOID:UINT (/usr/obj/i386/glib2-2.2.3/glib-2.2.3/gobject/gmarshal.list:31) */
+/* VOID:UINT (./gmarshal.list:11) */
 extern void g_cclosure_marshal_VOID__UINT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -51,7 +52,7 @@ extern void g_cclosure_marshal_VOID__UINT (GClosure     *closure,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
 
-/* VOID:LONG (/usr/obj/i386/glib2-2.2.3/glib-2.2.3/gobject/gmarshal.list:32) */
+/* VOID:LONG (./gmarshal.list:12) */
 extern void g_cclosure_marshal_VOID__LONG (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -59,7 +60,7 @@ extern void g_cclosure_marshal_VOID__LONG (GClosure     *closure,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
 
-/* VOID:ULONG (/usr/obj/i386/glib2-2.2.3/glib-2.2.3/gobject/gmarshal.list:33) */
+/* VOID:ULONG (./gmarshal.list:13) */
 extern void g_cclosure_marshal_VOID__ULONG (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -67,7 +68,7 @@ extern void g_cclosure_marshal_VOID__ULONG (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:ENUM (/usr/obj/i386/glib2-2.2.3/glib-2.2.3/gobject/gmarshal.list:34) */
+/* VOID:ENUM (./gmarshal.list:14) */
 extern void g_cclosure_marshal_VOID__ENUM (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -75,7 +76,7 @@ extern void g_cclosure_marshal_VOID__ENUM (GClosure     *closure,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
 
-/* VOID:FLAGS (/usr/obj/i386/glib2-2.2.3/glib-2.2.3/gobject/gmarshal.list:35) */
+/* VOID:FLAGS (./gmarshal.list:15) */
 extern void g_cclosure_marshal_VOID__FLAGS (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -83,7 +84,7 @@ extern void g_cclosure_marshal_VOID__FLAGS (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:FLOAT (/usr/obj/i386/glib2-2.2.3/glib-2.2.3/gobject/gmarshal.list:36) */
+/* VOID:FLOAT (./gmarshal.list:16) */
 extern void g_cclosure_marshal_VOID__FLOAT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -91,7 +92,7 @@ extern void g_cclosure_marshal_VOID__FLOAT (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:DOUBLE (/usr/obj/i386/glib2-2.2.3/glib-2.2.3/gobject/gmarshal.list:37) */
+/* VOID:DOUBLE (./gmarshal.list:17) */
 extern void g_cclosure_marshal_VOID__DOUBLE (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -99,7 +100,7 @@ extern void g_cclosure_marshal_VOID__DOUBLE (GClosure     *closure,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
 
-/* VOID:STRING (/usr/obj/i386/glib2-2.2.3/glib-2.2.3/gobject/gmarshal.list:38) */
+/* VOID:STRING (./gmarshal.list:18) */
 extern void g_cclosure_marshal_VOID__STRING (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -107,7 +108,7 @@ extern void g_cclosure_marshal_VOID__STRING (GClosure     *closure,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
 
-/* VOID:PARAM (/usr/obj/i386/glib2-2.2.3/glib-2.2.3/gobject/gmarshal.list:39) */
+/* VOID:PARAM (./gmarshal.list:19) */
 extern void g_cclosure_marshal_VOID__PARAM (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -115,7 +116,7 @@ extern void g_cclosure_marshal_VOID__PARAM (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:BOXED (/usr/obj/i386/glib2-2.2.3/glib-2.2.3/gobject/gmarshal.list:40) */
+/* VOID:BOXED (./gmarshal.list:20) */
 extern void g_cclosure_marshal_VOID__BOXED (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -123,7 +124,7 @@ extern void g_cclosure_marshal_VOID__BOXED (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:POINTER (/usr/obj/i386/glib2-2.2.3/glib-2.2.3/gobject/gmarshal.list:41) */
+/* VOID:POINTER (./gmarshal.list:21) */
 extern void g_cclosure_marshal_VOID__POINTER (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -131,7 +132,7 @@ extern void g_cclosure_marshal_VOID__POINTER (GClosure     *closure,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
 
-/* VOID:OBJECT (/usr/obj/i386/glib2-2.2.3/glib-2.2.3/gobject/gmarshal.list:42) */
+/* VOID:OBJECT (./gmarshal.list:22) */
 extern void g_cclosure_marshal_VOID__OBJECT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -139,15 +140,15 @@ extern void g_cclosure_marshal_VOID__OBJECT (GClosure     *closure,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
 
-/* STRING:OBJECT,POINTER (/usr/obj/i386/glib2-2.2.3/glib-2.2.3/gobject/gmarshal.list:43) */
-extern void g_cclosure_marshal_STRING__OBJECT_POINTER (GClosure     *closure,
-                                                       GValue       *return_value,
-                                                       guint         n_param_values,
-                                                       const GValue *param_values,
-                                                       gpointer      invocation_hint,
-                                                       gpointer      marshal_data);
+/* VOID:VARIANT (./gmarshal.list:23) */
+extern void g_cclosure_marshal_VOID__VARIANT (GClosure     *closure,
+                                              GValue       *return_value,
+                                              guint         n_param_values,
+                                              const GValue *param_values,
+                                              gpointer      invocation_hint,
+                                              gpointer      marshal_data);
 
-/* VOID:UINT,POINTER (/usr/obj/i386/glib2-2.2.3/glib-2.2.3/gobject/gmarshal.list:46) */
+/* VOID:UINT,POINTER (./gmarshal.list:26) */
 extern void g_cclosure_marshal_VOID__UINT_POINTER (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
@@ -155,7 +156,7 @@ extern void g_cclosure_marshal_VOID__UINT_POINTER (GClosure     *closure,
                                                    gpointer      invocation_hint,
                                                    gpointer      marshal_data);
 
-/* BOOL:FLAGS (/usr/obj/i386/glib2-2.2.3/glib-2.2.3/gobject/gmarshal.list:47) */
+/* BOOL:FLAGS (./gmarshal.list:27) */
 extern void g_cclosure_marshal_BOOLEAN__FLAGS (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
@@ -164,6 +165,23 @@ extern void g_cclosure_marshal_BOOLEAN__FLAGS (GClosure     *closure,
                                                gpointer      marshal_data);
 #define g_cclosure_marshal_BOOL__FLAGS	g_cclosure_marshal_BOOLEAN__FLAGS
 
+/* STRING:OBJECT,POINTER (./gmarshal.list:28) */
+extern void g_cclosure_marshal_STRING__OBJECT_POINTER (GClosure     *closure,
+                                                       GValue       *return_value,
+                                                       guint         n_param_values,
+                                                       const GValue *param_values,
+                                                       gpointer      invocation_hint,
+                                                       gpointer      marshal_data);
+
+/* BOOL:BOXED,BOXED (./gmarshal.list:29) */
+extern void g_cclosure_marshal_BOOLEAN__BOXED_BOXED (GClosure     *closure,
+                                                     GValue       *return_value,
+                                                     guint         n_param_values,
+                                                     const GValue *param_values,
+                                                     gpointer      invocation_hint,
+                                                     gpointer      marshal_data);
+#define g_cclosure_marshal_BOOL__BOXED_BOXED	g_cclosure_marshal_BOOLEAN__BOXED_BOXED
+
 G_END_DECLS
 
 #endif /* __G_MARSHAL_H__ */
